@@ -199,7 +199,7 @@ find_code = function(m, text) {
 # qq.options(RESET = TRUE)
 qqcat = function(text, envir = parent.frame(), code.pattern = NULL, file = "",
     sep = " ", fill = FALSE, labels = NULL, append = FALSE, cat_prefix = NULL,
-    strwrap = FALSE, strwrap_param = list()) {
+    strwrap = qq.options("cat_strwrap"), strwrap_param = list()) {
 	text = qq(text, envir, code.pattern)
 	if(strwrap) {
 		if(!inherits(strwrap_param, "list")) {
@@ -216,7 +216,7 @@ qqcat = function(text, envir = parent.frame(), code.pattern = NULL, file = "",
 	cat(text, file = file, sep = sep, fill = fill, labels = labels, append = append, cat_prefix = cat_prefix)
 }
 
-cat = function(... , file = "", sep = " ", fill = FALSE, labels = NULL, append = FALSE, cat_prefix = NULL) {
+cat = function(..., file = "", sep = " ", fill = FALSE, labels = NULL, append = FALSE, cat_prefix = NULL) {
     
 	if(!is.null(options("cat_verbose")[[1]])) {
 		if(!options("cat_verbose")[[1]]) {
